summaryrefslogtreecommitdiffstats
path: root/kooka/ksaneocr.h
diff options
context:
space:
mode:
Diffstat (limited to 'kooka/ksaneocr.h')
-rw-r--r--kooka/ksaneocr.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kooka/ksaneocr.h b/kooka/ksaneocr.h
index d01be364..bc6b610e 100644
--- a/kooka/ksaneocr.h
+++ b/kooka/ksaneocr.h
@@ -260,14 +260,14 @@ private:
KSpell *m_spell;
bool m_wantKSpell;
- bool m_kspellVisible;
+ bool m_tdespellVisible;
bool m_hideDiaWhileSpellcheck;
KSpellConfig *m_spellInitialConfig;
/* ValueVector of wordLists for every line of ocr results */
ocrBlock m_ocrPage; /* one block contains all lines of the page */
TQWidget *m_parent;
/* current processed line to speed kspell correction */
unsigned m_ocrCurrLine;
TQStringList m_checkStrings;
@@ -260,14 +260,14 @@ private:
ocrBlock m_ocrPage; /* one block contains all lines of the page */
TQWidget *m_parent;
- /* current processed line to speed kspell correction */
+ /* current processed line to speed tdespell correction */
unsigned m_ocrCurrLine;
TQStringList m_checkStrings;